@@ -1,4 +1,4 @@
-#' MoE Method for ph Class
+#' MoE method for ph Class
 #'
 #' @param x An object of class \linkS4class{ph}.
 #' @param formula A regression formula.
@@ -8,7 +8,7 @@
 #' @param weight Vector of weights.
 #' @param delta Right-censoring indicator.
 #' @param stepsEM Number of EM steps to be performed.
-#' @param optim_method Method to use in gradient optimization
+#' @param optim_method Method to use in gradient optimization.
 #' @param maxit Maximum number of iterations when optimizing g function.
 #' @param reltol Relative tolerance when optimizing g function.
 #' @param every Number of iterations between likelihood display updates.
@@ -75,9 +75,24 @@ setMethod(
     names(ndm) <- names(dm)[-1]
     for (k in 1:stepsEM) {
       if (inh) {
-        B_matrix <- EMstep_MoE_PADE(alpha_vecs, S_fit, g_inv(x = frame[delta == 1, 1], theta = theta), weight[delta == 1], g_inv(x = frame[delta == 0, 1], theta = theta), weight[delta == 0])[[1]]
+        B_matrix_aux <- EMstep_MoE_PADE(rbind(alpha_vecs[delta == 1, ], alpha_vecs[delta == 0, ]), S_fit, g_inv(x = frame[delta == 1, 1], theta = theta), weight[delta == 1], g_inv(x = frame[delta == 0, 1], theta = theta), weight[delta == 0])
+        B_matrix <- B_matrix_aux[[1]]
         wt <- reshape2::melt(B_matrix)[, 3]
         wt[wt < 1e-22] <- wt[wt < 1e-22] + 1e-22
+        
+        B_matrix_cens <- B_matrix_aux[[2]]
+        wt_cens <- numeric(0)
+        if (nrow(B_matrix_cens) > 0) {
+          wt_cens <- reshape2::melt(B_matrix_cens)[, 3]
+          wt_cens[wt_cens < 1e-22] <- wt_cens[wt_cens < 1e-22] + 1e-22
+        }
+        wt_aux <- rep(0, length(wt) + length(wt_cens))
+        wt_aux[delta == 1] <- wt 
+        if (length(wt_cens) > 0) {
+          wt_aux[delta == 0] <- wt_cens
+        }
+        
+        wt <- wt_aux
         if (k == 1 | rand_init == TRUE) {
           multinom_model <- nnet::multinom(Class ~ ., data = dm, weights = wt, trace = F)
         } else {
@@ -103,9 +118,24 @@ setMethod(
           cat("\r", "iteration:", k, ", logLik:", -opt$value, sep = " ")
         }
       } else {
-        B_matrix <- EMstep_MoE_PADE(alpha_vecs, S_fit, frame[delta == 1, 1], weight[delta == 1], frame[delta == 0, 1], weight[delta == 0])[[1]]
+        B_matrix_aux <- EMstep_MoE_PADE(rbind(alpha_vecs[delta == 1, ], alpha_vecs[delta == 0, ]), S_fit, frame[delta == 1, 1], weight[delta == 1], frame[delta == 0, 1], weight[delta == 0])
+        B_matrix <- B_matrix_aux[[1]]
         wt <- reshape2::melt(B_matrix)[, 3]
         wt[wt < 1e-22] <- wt[wt < 1e-22] + 1e-22
+        
+        B_matrix_cens <- B_matrix_aux[[2]]
+        wt_cens <- numeric(0)
+        if (nrow(B_matrix_cens) > 0) {
+          wt_cens <- reshape2::melt(B_matrix_cens)[, 3]
+          wt_cens[wt_cens < 1e-22] <- wt_cens[wt_cens < 1e-22] + 1e-22
+        }
+        wt_aux <- rep(0, length(wt) + length(wt_cens))
+        wt_aux[delta == 1] <- wt 
+        if (length(wt_cens) > 0) {
+          wt_aux[delta == 0] <- wt_cens
+        }
+        
+        wt <- wt_aux
         if (k == 1 | rand_init == TRUE) {
           multinom_model <- nnet::multinom(Class ~ ., data = dm, weights = wt, trace = F)
         } else {
@@ -120,6 +150,6 @@ setMethod(
     }
     if (inh) inhom$theta <- theta
     cat("\n", sep = "")
-    return(list(alpha = alpha_vecs, S = S_fit, mm = multinom_model, inhom = inhom))
+    list(alpha = alpha_vecs, S = S_fit, mm = multinom_model, inhom = inhom)
   }
 )
